import React, { Component, Fragment } from 'react';
import { connect } from 'react-redux';
import { Redirect, Route, Switch } from 'react-router-dom';
import { IntlProvider } from 'react-intl';

import AppLocale from 'lang';
import MainRoute from 'routes';
import error from 'routes/error';

import 'assets/css/vendor/bootstrap.min.css';
import 'assets/css/sass/theme/thewom.scss';
// Consider using react-perfect-scrollbar as the default scroll-bar of the whole project
// import "react-perfect-scrollbar/dist/css/styles.css";

import { defaultConstants } from '_constants';

class App extends Component {
  render() {
    const { location, match, locale } = this.props;
    const currentAppLocale = AppLocale[locale];

    if (
      location.pathname === '/' ||
      location.pathname === '/site' ||
      location.pathname === '/site/'
    ) {
      return <Redirect to={defaultConstants.defaultStartPath} />;
    }
    // return <h1>Hello World</h1>;
    return (
      <Fragment>
        <IntlProvider
          locale={currentAppLocale.locale}
          messages={currentAppLocale.messages}
        >
          <Fragment>
            {/*<Main application*/}
            <Switch>
              <Route path={`${match.url}site`} component={MainRoute} />
              <Route path={`/error`} component={error} />
              <Redirect to="/error" />
            </Switch>
          </Fragment>
        </IntlProvider>
      </Fragment>
    );
  }
}

const mapStateToProps = ({ settings, user }) => {
  const { locale } = settings;
  return {
    locale,
    user,
  };
};

export default connect(mapStateToProps)(App);
